@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 # package exports and version
-our $VERSION   = '0.55';
+our $VERSION   = '0.56';
 our @EXPORT_OK = ();
 
 # module imports
@@ -53,6 +53,9 @@ sub new {
 	$self->Fit;
 	$self->CentreOnParent;
 
+	# Dialog's icon as is the same as plugin's
+	$self->SetIcon( $plugin->logo_icon );
+
 	return $self;
 }
 
